@@ -3,10 +3,10 @@ package Crypt::Passphrase::Argon2::AES;
 use strict;
 use warnings;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use parent 'Crypt::Passphrase::Argon2::Encrypted';
-use Crypt::Passphrase 0.010 -encoder;
+use Crypt::Passphrase 0.019 -encoder;
 
 use Carp 'croak';
 use Crypt::Rijndael 1.16;
@@ -25,11 +25,12 @@ sub new {
 	$args{active} //= (sort {; no warnings 'numeric'; $b <=> $a || $b cmp $a } keys %{ $peppers })[0];
 	my $mode = delete $args{mode} // 'cbc';
 	my $cipher = "aes-$mode";
-	croak("No such mode $mode") if not exists $mode{$cipher};
-	my $self = $class->SUPER::new(%args, cipher => $cipher);
+	croak "No such mode $mode" if not exists $mode{$cipher};
+	my $self = $class->SUPER::new(%args, cipher => $cipher, salt_size => 16);
+	croak "Output size must be a double of 16 for CBC and ECB" if ($mode eq 'cbc' || $mode eq 'ecb') && $self->{output_size} % 16;
 	for my $key (keys %{$peppers}) {
 		my $length = length $peppers->{$key};
-		die "Pepper $key has invalid length $length" if $length != 16 && $length != 24 && $length != 32;
+		croak "Pepper $key has invalid length $length" if $length != 16 && $length != 24 && $length != 32;
 		$self->{peppers}{$key} = $peppers->{$key};
 	}
 	return $self;
@@ -103,9 +104,11 @@ This is the mode that will be used with C<AES>. Values values are C<'ecb'>, C<'c
 
 =back
 
+The C<salt_size> is hard-coded to 16 bytes, and if C<mode> equals C<cbc> or C<ecb>, the C<output_size> must be a multiple of 16 bytes.
+
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
